@@ -1,9 +1,10 @@
 package WebService::Client;
 use Moo::Role;
 
-our $VERSION = '0.0400'; # VERSION
+our $VERSION = '0.0500'; # VERSION
 
 use Carp qw(croak);
+use HTTP::Request;
 use HTTP::Request::Common qw(DELETE GET POST PUT);
 use JSON qw(decode_json encode_json);
 use LWP::UserAgent;
@@ -85,6 +86,15 @@ sub put {
     return $self->req($req, %args);
 }
 
+sub patch {
+    my ($self, $path, $data, %args) = @_;
+    my $headers = $self->_headers(\%args);
+    my $url = $self->_url($path);
+    my $req = HTTP::Request->new(
+        'PATCH', $url, [%$headers], $self->_content($data, %args));
+    return $self->req($req, %args);
+}
+
 sub delete {
     my ($self, $path, %args) = @_;
     my $headers = $self->_headers(\%args);
@@ -199,7 +209,7 @@ WebService::Client - A base role for quickly and easily creating web service cli
 
 =head1 VERSION
 
-version 0.0400
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -322,6 +332,12 @@ Makes an HTTP POST request.
 
 Makes an HTTP PUT request.
 
+=head2 patch
+
+    $client->patch('/foo', { some => 'data' });
+
+Makes an HTTP PATCH request.
+
 =head2 delete
 
     $client->delete('/foo');
